@@ -2,7 +2,7 @@
    Please see the COPYRIGHT file -}
 
 module Types where
-import Data.String
+import Data.String.Utils
 import Data.List
 import System.Console.GetOpt
 
